@@ -200,7 +200,7 @@
 /* #undef WORDS_BIGENDIAN */
 
 /* gPhoto2 library */
-#define HAVE_GPHOTO2
+/* #undef HAVE_GPHOTO2 */
 
 /* VA library (libva) */
 /* #undef HAVE_VA */
